@@ -15,7 +15,7 @@ package Benchmark::Perl::Formance::Plugin::Shootout::fasta;
 use strict;
 use warnings;
 
-our $VERSION = "0.001";
+our $VERSION = "0.002";
 
 #############################################################
 #                                                           #
@@ -151,7 +151,7 @@ sub main
         my ($options) = @_;
 
         $PRINT     = $options->{D}{Shootout_fasta_print};
-        my $goal   = $options->{D}{Shootout_fasta_n}     || ($options->{fastmode} ? 5000 : 5_000_000);
+        my $goal   = $options->{D}{Shootout_fasta_n}     || ($options->{fastmode} ? 20_000 : 5_000_000);
         my $count  = $options->{D}{Shootout_fasta_count} || ($options->{fastmode} ? 1 : 5);
 
         my $result;
